==> cloudt-boot-starter-log-3.2.5.96.15-20231226.060608-1-sources.jar: com/elitescloud/boot/log/service/OperationLogMqMessageDefaultServiceImpl.java <==
package com.elitescloud.boot.log.service;

import com.elitescloud.boot.log.model.bo.OperationLogDTO;
import com.elitescloud.boot.log.common.OperationTypeEnum;
import com.elitescloud.cloudt.common.base.ApiResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.env.Environment;

/**
 * @author : chen.niu
 * @description : 关闭操作日志实现
 * @date : 2023-11-28 17:41
 */
@Slf4j
public class OperationLogMqMessageDefaultServiceImpl
        implements OperationLogMqMessageService {
    private final Environment environment;

    public OperationLogMqMessageDefaultServiceImpl(Environment environment) {
        this.environment = environment;
    }

    @Override
    public ApiResult<String> sendSyncOperationLogMqMessage(OperationLogDTO operationLogDTO) {
        log.info("操作日志配置关闭，不发送日志: {}",operationLogDTO);
         return ApiResult.ok("操作日志配置关闭，不发送日志");
    }

    @Override
    public ApiResult<String> sendAsyncOperationLogMqMessage(OperationLogDTO operationLogDTO) {
        log.info("操作日志配置关闭，不发送日志: {}",operationLogDTO);
        return ApiResult.ok("操作日志配置关闭，不发送日志");
    }

    @Override
    public OperationLogDTO quickNewOperationLogDTO(
            Enum businessType, String businessParam,
            OperationTypeEnum operationType, String operationDescription) {
        return OperationLogMqMessageServiceImpl.getOperationLogDTO(businessType.name(),
                businessParam,
                operationType, operationDescription,environment);
     }

    @Override
    public OperationLogDTO quickNewOperationLogDTO(String businessType, String businessParam, OperationTypeEnum operationType, String operationDescription) {
        return OperationLogMqMessageServiceImpl.getOperationLogDTO(businessType,
                businessParam,
                operationType, operationDescription,environment);
    }




}

==> cloudt-boot-starter-log-3.3.14-0415-20240409.081101-2-sources.jar: com/elitescloud/boot/log/service/OperationLogMqMessageDefaultServiceImpl.java <==
package com.elitescloud.boot.log.service;

import com.elitescloud.boot.log.model.bo.OperationLogDTO;
import com.elitescloud.boot.common.annotation.businessobject.OperationTypeEnum;
import com.elitescloud.cloudt.common.base.ApiResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.env.Environment;

/**
 * @author : chen.niu
 * @description : 关闭操作日志实现
 * @date : 2023-11-28 17:41
 */
@Slf4j
public class OperationLogMqMessageDefaultServiceImpl
        implements OperationLogMqMessageService {
    private final Environment environment;

    public OperationLogMqMessageDefaultServiceImpl(Environment environment) {
        this.environment = environment;
    }

    @Override
    public ApiResult<String> sendSyncOperationLogMqMessage(OperationLogDTO operationLogDTO) {
        log.info("操作日志配置关闭，不发送日志: {}",operationLogDTO);
         return ApiResult.ok("操作日志配置关闭，不发送日志");
    }

    @Override
    public ApiResult<String> sendAsyncOperationLogMqMessage(OperationLogDTO operationLogDTO) {
        log.info("操作日志配置关闭，不发送日志: {}",operationLogDTO);
        return ApiResult.ok("操作日志配置关闭，不发送日志");
    }

    @Override
    public OperationLogDTO quickNewOperationLogDTO(
            Enum businessType, String businessParam,
            OperationTypeEnum operationType, String operationDescription) {
        return OperationLogMqMessageServiceImpl.getOperationLogDTO(businessType.name(),
                businessParam,
                operationType, operationDescription,environment);
     }

    @Override
    public OperationLogDTO quickNewOperationLogDTO(Enum businessType, String businessParam, com.elitescloud.boot.log.common.OperationTypeEnum operationType, String operationDescription) {
        return OperationLogMqMessageServiceImpl.getOperationLogDTO(businessType.name(),
                businessParam,
                operationType, operationDescription,environment);
    }

    @Override
    public OperationLogDTO quickNewOperationLogDTO(String businessType, String businessParam, OperationTypeEnum operationType, String operationDescription) {
        return OperationLogMqMessageServiceImpl.getOperationLogDTO(businessType,
                businessParam,
                operationType, operationDescription,environment);
    }

    @Override
    public OperationLogDTO quickNewOperationLogDTO(String businessType, String businessParam, com.elitescloud.boot.log.common.OperationTypeEnum operationType, String operationDescription) {
        return OperationLogMqMessageServiceImpl.getOperationLogDTO(businessType,
                businessParam,
                operationType, operationDescription,environment);
    }
}
